@@ -10,11 +10,17 @@ Usage::
     client: ElasticTranscoderClient = boto3.client("elastictranscoder")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_elastictranscoder.literals import (
+    JobCompleteWaiterName,
+    ListJobsByPipelinePaginatorName,
+    ListJobsByStatusPaginatorName,
+    ListPipelinesPaginatorName,
+    ListPresetsPaginatorName,
+)
 from mypy_boto3_elastictranscoder.paginator import (
     ListJobsByPipelinePaginator,
     ListJobsByStatusPaginator,
@@ -47,12 +53,6 @@ from mypy_boto3_elastictranscoder.type_defs import (
 )
 from mypy_boto3_elastictranscoder.waiter import JobCompleteWaiter
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("ElasticTranscoderClient",)
 
 
@@ -236,7 +236,7 @@ class ElasticTranscoderClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_jobs_by_pipeline"]
+        self, operation_name: ListJobsByPipelinePaginatorName
     ) -> ListJobsByPipelinePaginator:
         """
         [Paginator.ListJobsByPipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)
@@ -244,25 +244,25 @@ class ElasticTranscoderClient:
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_jobs_by_status"]
+        self, operation_name: ListJobsByStatusPaginatorName
     ) -> ListJobsByStatusPaginator:
         """
         [Paginator.ListJobsByStatus documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
+    def get_paginator(self, operation_name: ListPipelinesPaginatorName) -> ListPipelinesPaginator:
         """
         [Paginator.ListPipelines documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_presets"]) -> ListPresetsPaginator:
+    def get_paginator(self, operation_name: ListPresetsPaginatorName) -> ListPresetsPaginator:
         """
         [Paginator.ListPresets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)
         """
 
-    def get_waiter(self, waiter_name: Literal["job_complete"]) -> JobCompleteWaiter:
+    def get_waiter(self, waiter_name: JobCompleteWaiterName) -> JobCompleteWaiter:
         """
         [Waiter.JobComplete documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete)
         """
